==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/link/lang/si.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'si', {
	acccessKey: 'ප්‍රවේශ  යතුර',
	advanced: 'දීය',
	advisoryContentType: 'උපදේශාත්මක අන්තර්ගත ආකාරය',
	advisoryTitle: 'උපදේශාත්මක නාමය',
	anchor: {
		toolbar: 'ආධාරය',
		menu: 'ආධාරය වෙනස් කිරීම',
		title: 'ආධාරක ',
		name: 'ආධාරකයේ නාමය',
		errorName: 'කරුණාකර ආධාරකයේ නාමය ඇතුල් කරන්න',
		remove: 'ආධාරකය ඉවත් කිරීම'
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'විලාසපත්‍ර පන්තිය',
	emailAddress: 'E-Mail Address', // MISSING
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Message Subject', // MISSING
	id: 'අංකය',
	info: 'Link Info', // MISSING
	langCode: 'භාෂා කේතය',
	langDir: 'භාෂා දිශාව',
	langDirLTR: 'වමේසිට දකුණුට',
	langDirRTL: 'දකුණේ සිට වමට',
	menu: 'Edit Link', // MISSING
	name: 'නම',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Please type the e-mail address', // MISSING
	noUrl: 'Please type the link URL', // MISSING
	other: '<other>', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Relationship', // MISSING
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'විලාසය',
	tabIndex: 'Tab Index', // MISSING
	target: 'අරමුණ',
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'සබැඳිය',
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL',
	toolbar: 'සබැඳිය',
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'උඩුගතකිරීම'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/si.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'si', {
	acccessKey: 'ප්‍රවේශ  යතුර',
	advanced: 'දීය',
	advisoryContentType: 'උපදේශාත්මක අන්තර්ගත ආකාරය',
	advisoryTitle: 'උපදේශාත්මක නාමය',
	anchor: {
		toolbar: 'ආධාරය',
		menu: 'ආධාරය වෙනස් කිරීම',
		title: 'ආධාරක ',
		name: 'ආධාරකයේ නාමය',
		errorName: 'කරුණාකර ආධාරකයේ නාමය ඇතුල් කරන්න',
		remove: 'ආධාරකය ඉවත් කිරීම'
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'විලාසපත්‍ර පන්තිය',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail Address', // MISSING
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Message Subject', // MISSING
	id: 'අංකය',
	info: 'Link Info', // MISSING
	langCode: 'භාෂා කේතය',
	langDir: 'භාෂා දිශාව',
	langDirLTR: 'වමේසිට දකුණුට',
	langDirRTL: 'දකුණේ සිට වමට',
	menu: 'Edit Link', // MISSING
	name: 'නම',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Please type the e-mail address', // MISSING
	noUrl: 'Please type the link URL', // MISSING
	noTel: 'Please type the phone number', // MISSING
	other: '<other>', // MISSING
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Relationship', // MISSING
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'විලාසය',
	tabIndex: 'Tab Index', // MISSING
	target: 'අරමුණ',
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'සබැඳිය',
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'සබැඳිය',
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'උඩුගතකිරීම'
} );
